@@ -10,7 +10,7 @@ use Carp();
 
 use base qw(Exporter);
 our @EXPORT_OK = qw(is_holiday holidays);
-our $VERSION   = '0.26';
+our $VERSION   = '0.27';
 
 sub _DEFAULT_STATE { return 'VIC' }
 
@@ -894,13 +894,11 @@ sub _compute_vic_grand_final_eve_day {    # i have no words ...
         2018 => { day => 28, month => 8 },
         2019 => { day => 27, month => 8 },
         2020 => { day => 23, month => 9 },    # Technically "Thank you" day.
+        2021 => { day => 24, month => 8 },
     );
     if ( $year < 2015 ) {
         return ();
     }
-    elsif ( $year == 2021 ) {
-        return ();                            # not determined yet
-    }
     elsif ( $grand_final_eve_day{$year} ) {
         $day   = $grand_final_eve_day{$year}{day};
         $month = $grand_final_eve_day{$year}{month};
@@ -1263,7 +1261,7 @@ Date::Holidays::AU - Determine Australian Public Holidays
 
 =head1 VERSION
  
-Version 0.26
+Version 0.27
 
 =head1 SYNOPSIS
 
